yt.utilities.operator\_registry module
======================================

.. automodule:: yt.utilities.operator_registry
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
